---
title: Introducing FastAgency - the fastest way to bring AutoGen workflows to production - Nov 12, 2024
---

### Speakers: Davor Runje

### Biography of the speakers:

Davor Runje is a seasoned software engineer, computer scientist, and serial entrepreneur with a strong background in technology and business. Most recently, he co-founded an AI startup Airt. Prior to that, he co-founded and exited from two companies. Davor is a very active member of open source community. He is a maintainer of FastStream and FastAgency and a core contributor to AutoGen. During his PhD studies, under the mentorship of Dean Rosenzweig from the University of Zagreb and Yuri Gurevich at Microsoft Research, Davor made significant contributions to programming for multiprocessor/multicore systems. He made the design, implementation, and technology transfer of a system that facilitated structured concurrency program execution, which became known as the Task Parallel Library in the .NET framework. This earned him the SSCLI and Phoenix 2005 award from Microsoft Research, recognising it as one of the top 16 international research projects. Davor is also an esteemed academic author with over 20 publications in theoretical computer science and artificial intelligence. He also holds two US patents. Between 2020 and 2024, he served as the president of the board of CISEx, the largest software industry association in Croatia, advocating for legal and tax reforms to enhance the global competitiveness of the Croatian IT sector.

### Abstract:

Inspired by the design and philosophy of modern Python frameworks such as FastAPI, we designed a framework that allows you to go from a working multi-agent prototype written in AutoGen to a scalable, multi-tenant application with SSO authentication hosted on the cloud in less than one hour. Depending on your needs, you can quickly build a REST-based web service running multiple workers or, in the case of an even larger scale, a distributed service built around a message broker protocol. The framework is powerful and uses complex technologies under the hood, yet it is simple to use and it requires only a few lines of code to get the desired results. FastAgency also has a simple-to-use component that allows you to render rich information in UI, giving you a better way to communicate with the end user. Last but not least, FastAgency allows you to import external REST APIs using their OpenAPI specifications and automatically build tools that can be attached to agents in just a few lines of code. In this walk, I'll walk you over the core concepts behind the framework and illustrate them with examples.
